@@ -16,11 +16,11 @@ class BrowserBridge(DatabaseMixin, Bridge):
         self.elements = []
 
     @property
-    def driver(self):
+    def web_driver(self):
         return self.ctx.webdriver
 
-    @driver.setter
-    def driver(self, value):
+    @web_driver.setter
+    def web_driver(self, value):
         self.ctx.webdriver = value
 
     @property
@@ -31,7 +31,7 @@ class BrowserBridge(DatabaseMixin, Bridge):
     def url(self):
         current_url = None
         if self.is_running:
-            current_url = self.driver.url
+            current_url = self.web_driver.url
         return current_url
 
     def status(self):
@@ -58,7 +58,7 @@ class BrowserBridge(DatabaseMixin, Bridge):
     def connect(self, browser):
         if browser["type"] == "selenium":
             self.logger.info("Connecting to remote webdriver: %s", browser)
-            self.driver = WebDriver.from_remote(
+            self.web_driver = WebDriver.from_remote(
                 browser["executor_url"],
                 browser["session_id"],
                 browser["handle"],
@@ -71,39 +71,42 @@ class BrowserBridge(DatabaseMixin, Bridge):
         is_new_session = not self.is_running
         self.logger.info("Is it a new session?: %s", is_new_session)
         if is_new_session:
-            self.driver = WebDriver()
-            self.driver.start()
+            self.web_driver = WebDriver()
+            self.web_driver.start()
 
         if url is not None and str(url).strip():
-            self.driver.navigate(url)
+            self.web_driver.navigate(url)
             response = {"url": url}
         elif is_new_session:
             self.show_guide()
             response = {"url": ""}
         else:
-            response = {"url": self.driver.url}
+            response = {"url": self.web_driver.url}
 
         return response
 
     @traceback
     def show_guide(self):
-        self.driver.show_guide("inspect-guide")
+        self.web_driver.show_guide("inspect-guide")
 
     @traceback
     def stop(self):
-        if self.driver:
-            self.driver.stop()
+        self.logger.debug("Destroying window...")
+        self.close()
+        self.logger.debug("Destroying web driver...")
+        self.web_driver.stop()
+        self.logger.debug("Stopped browser!!!")
 
     @traceback
     def pick(self):
         if not self.is_running:
             raise RuntimeError("No active browser session")
 
-        self.driver.clear()
+        self.web_driver.clear()
         try:
-            return self.driver.pick()
+            return self.web_driver.pick()
         except WebDriverError as err:
-            self.driver.cancel_pick()
+            self.web_driver.cancel_pick()
             raise err
 
     @traceback
@@ -112,21 +115,21 @@ class BrowserBridge(DatabaseMixin, Bridge):
             raise RuntimeError("No active browser session")
 
         try:
-            self.driver.clear()
-            self.elements = self.driver.find(strategy, value)
+            # self.web_driver.clear()
+            self.elements = self.web_driver.find(strategy, value)
             if not self.elements:
                 raise ValueError("No matches found")
 
             screenshot = self.elements[0].screenshot_as_base64
-            matches = self.driver.highlight(self.elements, hide=hide_highlights)
+            matches = self.web_driver.highlight(self.elements, hide=hide_highlights)
         except Exception as exc:  # pylint: disable=broad-except
             self.logger.info("Failed to validate: %s", exc)
             self.elements = []
             screenshot = ""
             matches = []
 
-        if not self.driver.url.startswith("data:text/html"):
-            source = self.driver.url
+        if not self.web_driver.url.startswith("data:text/html"):
+            source = self.web_driver.url
         else:
             source = ""
 
@@ -147,7 +150,7 @@ class BrowserBridge(DatabaseMixin, Bridge):
             return
 
         self.logger.debug("Focusing element #%d: %s", match_id, friendly_name(element))
-        self.driver.focus(element)
+        self.web_driver.focus(element)
 
     def set_window_height(self, height):
         self.logger.debug(
