@@ -2,11 +2,13 @@ import base64
 import logging
 import os
 import platform
+import signal
 import traceback
 from pathlib import Path, WindowsPath
-from typing import Dict
+from typing import Dict, Union
 from urllib.parse import urlparse
 
+import psutil  # type: ignore
 from RPA.core import webdriver  # type: ignore
 from selenium.common.exceptions import (  # type: ignore
     InvalidSessionIdException,
@@ -109,7 +111,7 @@ class WebDriverError(Exception):
 
 
 class WebDriver:
-    SCRIPT_TIMEOUT = 30.0  # seconds
+    SCRIPT_TIMEOUT = 120.0  # seconds
 
     def __init__(self):
         self.logger = logging.getLogger(__name__)
@@ -117,6 +119,7 @@ class WebDriver:
         self.resources = {}
         self.is_remote = False
         self._load_resources()
+        self._is_recording: bool = False
 
     @classmethod
     def from_remote(cls, executor_url, session_id, handle):
@@ -182,7 +185,6 @@ class WebDriver:
         self.resources = {
             "style": load_resource("inspector.css"),
             "inspector": load_resource("inspector.js"),
-            "web-recorder": load_resource("webRecorder.js"),
             "inspect-guide": load_resource("guide.html"),
             "recording-guide": load_resource("browser-recording-guide.html"),
         }
@@ -192,15 +194,17 @@ class WebDriver:
         if not self.selenium.find_elements_by_id("inspector-style"):
             self.logger.debug("Injecting resources to web page...")
             self.selenium.execute_script(self.resources["inspector"])
-            self.logger.debug("[DONE] Injecting inspector!")
-            self.selenium.execute_script(self.resources["web-recorder"])
-            self.logger.debug("[DONE] Injecting web-recorder!")
+            self.logger.debug("[DONE] Inspector code injected!")
             self.selenium.execute_script(
                 'var style = document.getElementById("inspector-style");'
                 f'var content = document.createTextNode(`{self.resources["style"]}`);'
                 "style.appendChild(content);"
             )
-            self.logger.debug("[DONE] Injecting inspector-style!")
+            self.logger.debug("[DONE] Inspector style injected!")
+        else:
+            self.logger.error(
+                "Inspector already injected or did not manage to inject code!"
+            )
 
     def _exec_driver(self, func, *args, **kwargs):
         def error(msg, *error_args):
@@ -298,17 +302,44 @@ class WebDriver:
         self.selenium.set_script_timeout(self.SCRIPT_TIMEOUT)
 
     def stop(self):
+        self.logger.debug("Trying to stop driver...")
         if not self.selenium:
+            self.logger.debug("Skipping close as no selenium present")
             return
 
         if self.is_remote:
             self.logger.debug("Skipping close for remote browser")
             return
 
-        self.logger.debug("Stopping browser")
-        self.selenium.close()
-        self.selenium.quit()
-        self.logger.debug("Browser stopped!")
+        try:
+            if not self._is_recording:
+                self.logger.debug("[DEFAULT] Stopping browser")
+                self.selenium.close()
+                self.selenium.quit()
+                self.logger.debug("[DEFAULT] Browser stopped!")
+            else:
+                self.logger.debug("[DEFAULT] Skipped normally stopping browser. ")
+
+            if self.selenium:
+                self.logger.debug(
+                    "[FORCE] Stopping browser: %s", self.selenium.service.process.pid
+                )
+                browser_proc = psutil.Process(self.selenium.service.process.pid)
+                for child in browser_proc.children(recursive=True):
+                    try:
+                        self.logger.debug("[FORCE] Stopping process: %s", child.pid)
+                        os.kill(child.pid, signal.SIGTERM)
+                        child.kill()
+                        child.wait()
+                    except Exception:  # pylint: disable=W0703
+                        pass
+                self.logger.debug("[FORCE] Browser stopped!")
+            else:
+                self.logger.debug("[FORCE] Skipped force stopping browser.")
+
+        except Exception as ex:  # pylint: disable=W0703
+            self.logger.error("There was an error while stopping driver: %s", ex)
+
         self.selenium = None
 
     def show_guide(self, guide_resources: str):
@@ -395,18 +426,31 @@ callback(tags);
         return self._exec_script("Inspector.removeHighlights();")
 
     def cancel_pick(self):
-        self.logger.debug("Canceling picking and clearing highlighs")
+        self.logger.debug("Canceling picking and clearing highlights")
         return self._exec_script("Inspector.cancelPick();")
 
-    def record_event(self) -> Dict:
-        self._exec_resources()
+    def record_event(self) -> Union[Dict, None]:
+        try:
+            self._is_recording = True
+            self._exec_resources()
 
-        result = self.selenium.execute_async_script(
-            "var callback = arguments[arguments.length - 1];"
-            "Recorder.recordEvent(callback);"
-        )
-        self.logger.debug("Selenium execute async script finished, result: %s", result)
-        return result
+            result = self.selenium.execute_async_script(
+                "var callback = arguments[arguments.length - 1];"
+                "Inspector.recordEvent(callback);"
+            )
+            self.logger.debug(
+                "Selenium execute async script finished, result: %s", result
+            )
+            self._is_recording = False
+            return result
+        except Exception as ex:  # pylint: disable=W0703
+            self.logger.error("There was an exception while recording event: %s", ex)
+            return None
 
     def stop_recording(self) -> None:
-        self.selenium.execute_script("Recorder.stop();")
+        try:
+            if self._is_recording:
+                self.selenium.execute_script("Inspector.stopRecording();")
+        except Exception as ex:  # pylint: disable=W0703
+            self.logger.error("There was an exception while recording event: %s", ex)
+        self._is_recording = False
